/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.semanticweb.owlapi.util;

import org.semanticweb.owlapi.model.OWLAnnotationProperty;
import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLDataProperty;
import org.semanticweb.owlapi.model.OWLDatatype;
import org.semanticweb.owlapi.model.OWLEntity;
import org.semanticweb.owlapi.model.OWLEntityVisitorEx;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.semanticweb.owlapi.model.OWLObjectProperty;


/**
 * Author: Matthew Horridge<br> The University Of Manchester<br> Information Management Group<br> Date:
 * 29-Jul-2008<br><br>
 *
 * Provides a default implementation of <code>OWLObjectVisitorEx</code>.  Only the methods that need specific client
 * implementation need be overridden.  The adapter can be set up to return a default value.
 */
@SuppressWarnings("javadoc")
public class OWLEntityVisitorExAdapter<O> implements OWLEntityVisitorEx<O> {

    private O defaultReturnValue = null;

    /** Gets the default return value for this visitor. By default, the default
     * is <code>null</code>, but a fixed value (independent of the specified
     * <code>OWLObject</code> <code>object</code>) can be specified in the
     * constructor
     * {@link org.semanticweb.owlapi.util.OWLObjectVisitorExAdapter#OWLObjectVisitorExAdapter(Object)}
     * 
     * @param object
     *            The object that was visited.
     * @return The default return value */
    @SuppressWarnings("unused")
    protected O getDefaultReturnValue(OWLEntity object) {
        return defaultReturnValue;
    }

    public OWLEntityVisitorExAdapter() {
        this(null);
    }

    public OWLEntityVisitorExAdapter(O defaultReturnValue) {
        this.defaultReturnValue = defaultReturnValue;
    }

    @Override
    public O visit(OWLClass desc) {
        return getDefaultReturnValue(desc);
    }

    @Override
    public O visit(OWLDatatype node) {
        return getDefaultReturnValue(node);
    }

    @Override
    public O visit(OWLDataProperty property) {
        return getDefaultReturnValue(property);
    }

    @Override
    public O visit(OWLObjectProperty property) {
        return getDefaultReturnValue(property);
    }

    @Override
    public O visit(OWLNamedIndividual individual) {
        return getDefaultReturnValue(individual);
    }

    @Override
    public O visit(OWLAnnotationProperty property) {
        return getDefaultReturnValue(property);
    }
}
